about summary refs log tree commit diff
path: root/src/fstate.hh
diff options
context:
space:
mode:
authorEelco Dolstra <e.dolstra@tudelft.nl>2003-07-08T13·22+0000
committerEelco Dolstra <e.dolstra@tudelft.nl>2003-07-08T13·22+0000
commit40274c1f4f763e634dd031f7a6b4ba8ce2de7a82 (patch)
tree87f701e59cbe12fc86a9e67aa04ac1321533400c /src/fstate.hh
parenta279137327ad5762bb26a23ce8ed7863812254ae (diff)
* A command to query the paths referenced by an fstate expression.
* Use a temporary directory for build actions.

Diffstat (limited to 'src/fstate.hh')
-rw-r--r--src/fstate.hh13
1 files changed, 12 insertions, 1 deletions
diff --git a/src/fstate.hh b/src/fstate.hh
index b04588e7b35b..de6303dca1e4 100644
--- a/src/fstate.hh
+++ b/src/fstate.hh
@@ -60,9 +60,17 @@ typedef ATerm FState;
 typedef ATerm Content;
 
 
-/* Realise a $f$-normalised expression in the file system. */
+/* Realise an fstate expression in the file system.  This requires
+   execution of all Derive() nodes. */
 FState realiseFState(FState fs);
 
+/* Return the path of an fstate expression.  An empty string is
+   returned if the term is not a valid fstate expression. (!!!) */
+string fstatePath(FState fs);
+
+/* Return the paths referenced by fstate expression. */
+Strings fstateRefs(FState fs);
+
 /* Return a canonical textual representation of an expression. */
 string printTerm(ATerm t);
 
@@ -73,6 +81,9 @@ Error badTerm(const format & f, ATerm t);
 /* Hash an aterm. */
 Hash hashTerm(ATerm t);
 
+/* Read an aterm from disk, given its hash. */
+ATerm termFromHash(const Hash & hash);
+
 /* Write an aterm to the Nix store directory, and return its hash. */
 Hash writeTerm(ATerm t);